import React, { useEffect } from "react";
import { useState } from "react";
import { User, Flight } from "../Types";
import { fetchZones } from "../Api";
import { Stores, addData, deleteData, getStoreData, updateData, initDB } from '../db';

export const useFetchZones = () => {
	const [error, setError] = useState<string | null>(null);
	const [zones, setZones] = useState<Flight[]>([]);
    let origin = process.env.REACT_APP_ORIGIN;

	useEffect(() => {
		setError(null);
        let newUpdate = new Date().toISOString()

        getStoreData<Flight>(Stores.Flight)
            .then((data) => {
                console.log(data)
                if (data && data.length > 0) {
                    setZones(data)
                } else {
                    fetchZones(origin, null)
                        .then((data) => {
                            localStorage.setItem('lastUpdated', newUpdate)
                            setZones(data);
                            data.map((u) => {
                                addData(Stores.Flight, u)
                            })
                        })
                        .catch((error) => {});
                }
            })

	}, [origin]);

    useEffect(() => {
        const intervalId = setInterval(() => {
            let lastUpdate = localStorage.getItem('lastUpdated')
            let newUpdate = new Date().toISOString()

            fetchZones(origin, lastUpdate)
                        .then((data) => {
                            localStorage.setItem('lastUpdated', newUpdate)
                            let toAdd: Flight[] = []

                            zones.forEach((c, i) => {
                                let index = data.findIndex(x => x.id === c.id)
                                if (index >= 0) {
                                    toAdd.push(data[index]);
                                    console.log(",aria")
                                    updateData(Stores.Flight, String(c.id), data[index])
                                } else {
                                    toAdd.push(c);
                                } 
                            });

                            console.log(toAdd)
                            let filtered = data.filter(o => !toAdd.some(b => { return o.id === b.id} ))
                            const newArray = toAdd.concat(filtered);
                            filtered.forEach(c => {
                                addData(Stores.Flight, c)
                            })

                            setZones(newArray);
                        })
                        .catch((error) => {});
        }, 5000)
      
        return () => clearInterval(intervalId);
      }, [origin, zones])

	return { zones, error };
};
